//@line 36 "/builds/slave/rel-m-beta-lnx-mb-rpk-5/mozilla-beta/pa-IN/mobile/mobile-l10n.js"

//@line 38 "/builds/slave/rel-m-beta-lnx-mb-rpk-5/mozilla-beta/pa-IN/mobile/mobile-l10n.js"

pref("general.useragent.locale", "pa-IN");
